Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(878)

Unified Diff: content/public/test/layouttest_support.h

Issue 2238573002: Add WebWidgetTestProxy. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add missing files Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/test_runner/web_widget_test_proxy.cc ('k') | content/renderer/render_widget.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/test/layouttest_support.h
diff --git a/content/public/test/layouttest_support.h b/content/public/test/layouttest_support.h
index a188bb78bdb883280ff8a2582f393df59b12f817..d90830dd59c708a8ce62ef4d990b546a979e7846 100644
--- a/content/public/test/layouttest_support.h
+++ b/content/public/test/layouttest_support.h
@@ -25,6 +25,7 @@ class WebGamepads;
class WebLayer;
struct WebSize;
class WebView;
+class WebWidget;
class WebURLResponse;
}
@@ -35,6 +36,7 @@ class BluetoothAdapter;
namespace test_runner {
class WebFrameTestProxyBase;
class WebViewTestProxyBase;
+class WebWidgetTestProxyBase;
}
namespace content {
@@ -65,16 +67,23 @@ test_runner::WebViewTestProxyBase* GetWebViewTestProxyBase(
test_runner::WebFrameTestProxyBase* GetWebFrameTestProxyBase(
RenderFrame* render_frame);
// Enable injecting of a WebViewTestProxy between WebViews and RenderViews
// and WebFrameTestProxy between WebFrames and RenderFrames.
// |view_proxy_creation_callback| is invoked after creating WebViewTestProxy.
+// |widget_proxy_creation_callback| is invoked after creating
+// WebWidgetTestProxy.
// |frame_proxy_creation_callback| is called after creating WebFrameTestProxy.
using ViewProxyCreationCallback =
base::Callback<void(RenderView*, test_runner::WebViewTestProxyBase*)>;
+using WidgetProxyCreationCallback =
+ base::Callback<void(blink::WebWidget*,
+ test_runner::WebWidgetTestProxyBase*)>;
using FrameProxyCreationCallback =
base::Callback<void(RenderFrame*, test_runner::WebFrameTestProxyBase*)>;
void EnableWebTestProxyCreation(
const ViewProxyCreationCallback& view_proxy_creation_callback,
+ const WidgetProxyCreationCallback& widget_proxy_creation_callback,
const FrameProxyCreationCallback& frame_proxy_creation_callback);
typedef base::Callback<void(const blink::WebURLResponse& response,
« no previous file with comments | « components/test_runner/web_widget_test_proxy.cc ('k') | content/renderer/render_widget.h » ('j') | no next file with comments »
@@ -65,16 +67,23 @@ test_runner::WebViewTestProxyBase* GetWebViewTestProxyBase(
test_runner::WebFrameTestProxyBase* GetWebFrameTestProxyBase(
RenderFrame* render_frame);
-// Enable injecting of a WebViewTestProxy between WebViews and RenderViews
-// and WebFrameTestProxy between WebFrames and RenderFrames.
+// Enable injecting of a WebViewTestProxy between WebViews and RenderViews,
+// WebWidgetTestProxy between WebWidgets and RenderWidgets and WebFrameTestProxy
+// between WebFrames and RenderFrames.
// |view_proxy_creation_callback| is invoked after creating WebViewTestProxy.

Powered by Google App Engine
This is Rietveld 408576698